@@ -1,10 +1,11 @@
-use 5.008;    # utf8
+use 5.006;    # our
 use strict;
 use warnings;
-use utf8;
 
 package MetaPOD::Exception;
-$MetaPOD::Exception::VERSION = '0.3.6';
+
+our $VERSION = 'v0.4.0';
+
 use Moo qw( extends );
 
 # ABSTRACT: Base class for MetaPOD exceptions.
@@ -41,7 +42,7 @@ MetaPOD::Exception - Base class for MetaPOD exceptions.
 
 =head1 VERSION
 
-version 0.3.6
+version v0.4.0
 
 =begin MetaPOD::JSON v1.1.0
 
@@ -56,11 +57,11 @@ version 0.3.6
 
 =head1 AUTHOR
 
-Kent Fredric <kentfredric@gmail.com>
+Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2017 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
