@@ -1,10 +1,11 @@
-use 5.008;    # utf8
+use 5.006;    # our
 use strict;
 use warnings;
-use utf8;
 
 package MetaPOD::Exception::Decode::Data;
-$MetaPOD::Exception::Decode::Data::VERSION = '0.3.6';
+
+our $VERSION = 'v0.4.0';
+
 # ABSTRACT: Failures with decoding source data
 
 our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
@@ -63,7 +64,7 @@ MetaPOD::Exception::Decode::Data - Failures with decoding source data
 
 =head1 VERSION
 
-version 0.3.6
+version v0.4.0
 
 =head1 ATTRIBUTES
 
@@ -88,11 +89,11 @@ Messages given from decoder
 
 =head1 AUTHOR
 
-Kent Fredric <kentfredric@gmail.com>
+Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2017 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
