@@ -1,10 +1,11 @@
-use 5.008;    # utf8
+use 5.006;    # our
 use strict;
 use warnings;
-use utf8;
 
 package MetaPOD::Role::Format;
-$MetaPOD::Role::Format::VERSION = '0.3.6';
+
+our $VERSION = 'v0.4.0';
+
 # ABSTRACT: Base role for common format routines
 
 our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
@@ -96,7 +97,7 @@ MetaPOD::Role::Format - Base role for common format routines
 
 =head1 VERSION
 
-version 0.3.6
+version v0.4.0
 
 =head1 METHODS
 
@@ -144,11 +145,11 @@ The default implementation just wraps L</supported_versions> with C<< version->p
 
 =head1 AUTHOR
 
-Kent Fredric <kentfredric@gmail.com>
+Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2017 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
